turtles-own
[
  ;; a number representing the group this turtle is a member of, or -1 if this
  ;; turtle is not in a group.
  my-group 
]

;;; ABOUT THE PROBLEM
;;;
;;; In some cases, you have a group of turtles that you wish to divide into
;;; groups of roughly the same size. In general, it's important that these
;;; groups be randomly composed, to minimize the possible effects of agent
;;; scheduling.  (In other words you don't want a group to be composed entirely
;;; of turtles with low who numbers, since "ask turtles" always gives the
;;; turtles turns in order by who number.)
;;;
;;; Note that if you have a fixed number of groups known in advance, there are
;;; probably better ways to do this, using breeds, for instance. The
;;; techniques here are only necessary when you need to dynamically modify the
;;; size or number of the groups.
;;;
;;; Conceptually, there are two basic ways to form groups: by desired group
;;; size, or by desired number of groups. In either case, if the target number
;;; evenly divides the total number of turtles, there's no problem. But if it
;;; doesn't, then we have to make some decisions.
;;;
;;; When creating groups of a fixed size, say k, it's most natural to form as
;;; many groups of k turtles as possible, and then consider the remainder of
;;; the turtles "extra", and create one smaller group containing only those
;;; turtles. That way, all but one of the groups will have the desired size.
;;;
;;; When creating a fixed number of groups, it's most natural to assign one
;;; turtle to each group, and continue in this way until all turtles have been
;;; assigned. This, for instance, is the strategy one would most likely adopt
;;; in trying to distribute a large number of ping-pong balls as evenly as
;;; possible among a fixed number of buckets. In this case, all the groups
;;; will have either size k or size k + 1, for some k.
;;;
;;; The following two procedures implement each of these strategies. Which is
;;; appropriate for your model depends on your requirements. Other variations
;;; on these schemes are, of course, possible.



;;; this procedure randomly assigns turtles to groups based on the desired
;;; size of the groups. all the groups will have the desired size except for
;;; at most one group, which contains the remainder of the turtles. more
;;; formally, if there are n turtles, and the desired group size is k, this
;;; procedure will produce j = floor (n / k) groups of k turtles, and if
;;; n mod k > 0, it will produce one group of n mod k turtles.
to assign-by-size
  locals [ unassigned current ]

  ;; all turtles are initially ungrouped
  ask turtles [ set my-group -1 ]
  set unassigned turtles

  ;; start with group 0 and loop to build each group
  set current 0
  while [any? unassigned]
  [
    ;; place a randomly chosen set of group-size turtles into the current
    ;; group. or, if there are less than group-size turtles left, place the
    ;; rest of the turtles in the current group.
    ask random-n-of (min (list group-size (count unassigned))) unassigned
      [ set my-group current ]
    ;; consider the next group.
    set current current + 1
    ;; remove grouped turtles from the pool of turtles to assign
    set unassigned unassigned with [my-group = -1]
  ]
end

;;; this procedure randomly assigns turtles to groups based on the desired
;;; number of groups. all the groups will have as close as possible to the
;;; same number of turtles. more formally, if there are n turtles, and the
;;; desired number of groups is j, then let the initial group size be 
;;; k = ceiling (n / j). this procedure will produce n mod j groups of size
;;; k and j - (n mod j) groups of size k - 1.
to assign-by-number
  locals [unassigned current tmp-group-size]

  ;; figure out the larger of the two group sizes
  set tmp-group-size ceiling (count turtles / number-of-groups)

  ;; all turtles are initially ungrouped
  ask turtles [ set my-group -1 ]
  set unassigned turtles

  ;; start with group 0 and loop to build each group
  set current 0
  while [any? unassigned]
  [
    ;; place a randomly chosen set of tmp-group-size turtles into the current group
    ask random-n-of tmp-group-size unassigned
      [ set my-group current ]
    ;; consider the next group. if we're done building the larger groups,
    ;; reduce the group size by 1 for the rest of the groups.
    set current current + 1
    if current = ((count turtles) mod number-of-groups)
      [ set tmp-group-size tmp-group-size - 1 ]
    ;; remove grouped turtles from the pool of turtles to assign
    set unassigned unassigned with [my-group = -1]
  ]
end

;;;
;;; the following procedures are used to implement the visualization in the
;;; graphics window, and really don't have anything to do with grouping.
;;; unless you're particularly interested, it's safe to ignore the rest of the
;;; code.
;;;

;;; sets up the model
to setup
  ca
  cct number-of-turtles
  [
    ;; we want the color to be related to the who number of the turtles, so
    ;; that it will be fairly obvious if turtles are grouped in an ordered way.
    set color scale-color green who (number-of-turtles / -4) (number-of-turtles * 1.2)
    ;; randomly place them initially
    setxy random-float screen-size-x
          random-float screen-size-y
    set heading random-float 360
    ;; turtles start out ungrouped
    set my-group -1
  ]
end

;; causes the turtles to run around, going to their group's "home" if they're
;; in a group.
to go
  ask turtles
  [
    ;; if i'm in a group, move towards "home" for my group
    if my-group != -1
      [ set heading towards get-home ]
    ;; wiggle a little and always move forward, to make sure turtles don't all
    ;; pile up
    lt random-float 5
    rt random-float 5
    fd 1
  ]
end

;; figures out the home patch for a group. this looks complicated, but the
;; idea is simple. we just want to lay the groups out in a regular grid,
;; evenly spaced throughout the world. we want the grid to be square, so in
;; some cases not all the positions are filled.
to-report get-home ;; turtle procedure
  locals [side]
  ;; calculate the minimum length of each side of our grid
  set side ceiling (sqrt (max values-from turtles [my-group] + 1))

  report patch
           ;; compute the x coordinate
           (round ((screen-size-x / side) * (my-group mod side)
             - screen-edge-x + int (screen-size-x / (side * 2))))
           ;; compute the y coordinate
           (round ((screen-size-y / side) * int (my-group / side)
             - screen-edge-y + int (screen-size-y / (side * 2))))
end
@#$#@#$#@
GRAPHICS-WINDOW
260
10
585
356
17
17
9.0
1
10
1
1
1

TEXTBOX
17
303
238
371
To group turtles into a fixed number of groups, each of similar size, select the number of groups and press assign-by-number.

TEXTBOX
16
135
224
192
To group turtles into groups of a particular size, select the size and press assign-by-size.

BUTTON
104
65
167
98
NIL
go
T
1
T
OBSERVER
T

BUTTON
17
412
247
445
NIL
assign-by-number
NIL
1
T
OBSERVER
T

BUTTON
15
228
245
261
NIL
assign-by-size
NIL
1
T
OBSERVER
T

SLIDER
15
193
245
226
group-size
group-size
1
100
16
1
1
NIL

BUTTON
15
65
84
98
NIL
setup
NIL
1
T
OBSERVER
T

SLIDER
17
377
247
410
number-of-groups
number-of-groups
1
100
16
1
1
NIL

SLIDER
15
20
195
53
number-of-turtles
number-of-turtles
0
100
50
1
1
NIL

CC-WINDOW
260
357
585
476
Command Center

@#$#@#$#@
This example demonstrates two different methods for dividing an arbitrary number of turtles into groups, either by desired group size, or by desired number of groups. Please see the procedures tab for details.
@#$#@#$#@
default
true
0
Polygon -7566196 true true 150 5 40 250 150 205 260 250

ant
true
0
Polygon -7566196 true true 136 61 129 46 144 30 119 45 124 60 114 82 97 37 132 10 93 36 111 84 127 105 172 105 189 84 208 35 171 11 202 35 204 37 186 82 177 60 180 44 159 32 170 44 165 60
Polygon -7566196 true true 150 95 135 103 139 117 125 149 137 180 135 196 150 204 166 195 161 180 174 150 158 116 164 102
Polygon -7566196 true true 149 186 128 197 114 232 134 270 149 282 166 270 185 232 171 195 149 186 149 186
Polygon -7566196 true true 225 66 230 107 159 122 161 127 234 111 236 106
Polygon -7566196 true true 78 58 99 116 139 123 137 128 95 119
Polygon -7566196 true true 48 103 90 147 129 147 130 151 86 151
Polygon -7566196 true true 65 224 92 171 134 160 135 164 95 175
Polygon -7566196 true true 235 222 210 170 163 162 161 166 208 174
Polygon -7566196 true true 249 107 211 147 168 147 168 150 213 150

arrow
true
0
Polygon -7566196 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

bee
true
0
Polygon -256 true false 152 149 77 163 67 195 67 211 74 234 85 252 100 264 116 276 134 286 151 300 167 285 182 278 206 260 220 242 226 218 226 195 222 166
Polygon -16777216 true false 150 149 128 151 114 151 98 145 80 122 80 103 81 83 95 67 117 58 141 54 151 53 177 55 195 66 207 82 211 94 211 116 204 139 189 149 171 152
Polygon -7566196 true true 151 54 119 59 96 60 81 50 78 39 87 25 103 18 115 23 121 13 150 1 180 14 189 23 197 17 210 19 222 30 222 44 212 57 192 58
Polygon -16777216 true false 70 185 74 171 223 172 224 186
Polygon -16777216 true false 67 211 71 226 224 226 225 211 67 211
Polygon -16777216 true false 91 257 106 269 195 269 211 255
Line -1 false 144 100 70 87
Line -1 false 70 87 45 87
Line -1 false 45 86 26 97
Line -1 false 26 96 22 115
Line -1 false 22 115 25 130
Line -1 false 26 131 37 141
Line -1 false 37 141 55 144
Line -1 false 55 143 143 101
Line -1 false 141 100 227 138
Line -1 false 227 138 241 137
Line -1 false 241 137 249 129
Line -1 false 249 129 254 110
Line -1 false 253 108 248 97
Line -1 false 249 95 235 82
Line -1 false 235 82 144 100

bird1
false
0
Polygon -7566196 true true 2 6 2 39 270 298 297 298 299 271 187 160 279 75 276 22 100 67 31 0

bird2
false
0
Polygon -7566196 true true 2 4 33 4 298 270 298 298 272 298 155 184 117 289 61 295 61 105 0 43

boat1
false
0
Polygon -1 true false 63 162 90 207 223 207 290 162
Rectangle -6524078 true false 150 32 157 162
Polygon -16776961 true false 150 34 131 49 145 47 147 48 149 49
Polygon -7566196 true true 158 33 230 157 182 150 169 151 157 156
Polygon -7566196 true true 149 55 88 143 103 139 111 136 117 139 126 145 130 147 139 147 146 146 149 55

boat2
false
0
Polygon -1 true false 63 162 90 207 223 207 290 162
Rectangle -6524078 true false 150 32 157 162
Polygon -16776961 true false 150 34 131 49 145 47 147 48 149 49
Polygon -7566196 true true 157 54 175 79 174 96 185 102 178 112 194 124 196 131 190 139 192 146 211 151 216 154 157 154
Polygon -7566196 true true 150 74 146 91 139 99 143 114 141 123 137 126 131 129 132 139 142 136 126 142 119 147 148 147

boat3
false
0
Polygon -1 true false 63 162 90 207 223 207 290 162
Rectangle -6524078 true false 150 32 157 162
Polygon -16776961 true false 150 34 131 49 145 47 147 48 149 49
Polygon -7566196 true true 158 37 172 45 188 59 202 79 217 109 220 130 218 147 204 156 158 156 161 142 170 123 170 102 169 88 165 62
Polygon -7566196 true true 149 66 142 78 139 96 141 111 146 139 148 147 110 147 113 131 118 106 126 71

box
true
0
Polygon -7566196 true true 45 255 255 255 255 45 45 45

butterfly1
true
0
Polygon -16777216 true false 151 76 138 91 138 284 150 296 162 286 162 91
Polygon -7566196 true true 164 106 184 79 205 61 236 48 259 53 279 86 287 119 289 158 278 177 256 182 164 181
Polygon -7566196 true true 136 110 119 82 110 71 85 61 59 48 36 56 17 88 6 115 2 147 15 178 134 178
Polygon -7566196 true true 46 181 28 227 50 255 77 273 112 283 135 274 135 180
Polygon -7566196 true true 165 185 254 184 272 224 255 251 236 267 191 283 164 276
Line -7566196 true 167 47 159 82
Line -7566196 true 136 47 145 81
Circle -7566196 true true 165 45 8
Circle -7566196 true true 134 45 6
Circle -7566196 true true 133 44 7
Circle -7566196 true true 133 43 8

circle
false
0
Circle -7566196 true true 35 35 230

person
false
0
Circle -7566196 true true 155 20 63
Rectangle -7566196 true true 158 79 217 164
Polygon -7566196 true true 158 81 110 129 131 143 158 109 165 110
Polygon -7566196 true true 216 83 267 123 248 143 215 107
Polygon -7566196 true true 167 163 145 234 183 234 183 163
Polygon -7566196 true true 195 163 195 233 227 233 206 159

sheep
false
15
Rectangle -1 true true 90 75 270 225
Circle -1 true true 15 75 150
Rectangle -16777216 true false 81 225 134 286
Rectangle -16777216 true false 180 225 238 285
Circle -16777216 true false 1 88 92

spacecraft
true
0
Polygon -7566196 true true 150 0 180 135 255 255 225 240 150 180 75 240 45 255 120 135

thin-arrow
true
0
Polygon -7566196 true true 150 0 0 150 120 150 120 293 180 293 180 150 300 150

truck-down
false
0
Polygon -7566196 true true 225 30 225 270 120 270 105 210 60 180 45 30 105 60 105 30
Polygon -8716033 true false 195 75 195 120 240 120 240 75
Polygon -8716033 true false 195 225 195 180 240 180 240 225

truck-left
false
0
Polygon -7566196 true true 120 135 225 135 225 210 75 210 75 165 105 165
Polygon -8716033 true false 90 210 105 225 120 210
Polygon -8716033 true false 180 210 195 225 210 210

truck-right
false
0
Polygon -7566196 true true 180 135 75 135 75 210 225 210 225 165 195 165
Polygon -8716033 true false 210 210 195 225 180 210
Polygon -8716033 true false 120 210 105 225 90 210

turtle
true
0
Polygon -7566196 true true 138 75 162 75 165 105 225 105 225 142 195 135 195 187 225 195 225 225 195 217 195 202 105 202 105 217 75 225 75 195 105 187 105 135 75 142 75 105 135 105

wolf
false
0
Rectangle -7566196 true true 15 105 105 165
Rectangle -7566196 true true 45 90 105 105
Polygon -7566196 true true 60 90 83 44 104 90
Polygon -16777216 true false 67 90 82 59 97 89
Rectangle -1 true false 48 93 59 105
Rectangle -16777216 true false 51 96 55 101
Rectangle -16777216 true false 0 121 15 135
Rectangle -16777216 true false 15 136 60 151
Polygon -1 true false 15 136 23 149 31 136
Polygon -1 true false 30 151 37 136 43 151
Rectangle -7566196 true true 105 120 263 195
Rectangle -7566196 true true 108 195 259 201
Rectangle -7566196 true true 114 201 252 210
Rectangle -7566196 true true 120 210 243 214
Rectangle -7566196 true true 115 114 255 120
Rectangle -7566196 true true 128 108 248 114
Rectangle -7566196 true true 150 105 225 108
Rectangle -7566196 true true 132 214 155 270
Rectangle -7566196 true true 110 260 132 270
Rectangle -7566196 true true 210 214 232 270
Rectangle -7566196 true true 189 260 210 270
Line -7566196 true 263 127 281 155
Line -7566196 true 281 155 281 192

wolf-left
false
3
Polygon -6524078 true true 117 97 91 74 66 74 60 85 36 85 38 92 44 97 62 97 81 117 84 134 92 147 109 152 136 144 174 144 174 103 143 103 134 97
Polygon -6524078 true true 87 80 79 55 76 79
Polygon -6524078 true true 81 75 70 58 73 82
Polygon -6524078 true true 99 131 76 152 76 163 96 182 104 182 109 173 102 167 99 173 87 159 104 140
Polygon -6524078 true true 107 138 107 186 98 190 99 196 112 196 115 190
Polygon -6524078 true true 116 140 114 189 105 137
Rectangle -6524078 true true 109 150 114 192
Rectangle -6524078 true true 111 143 116 191
Polygon -6524078 true true 168 106 184 98 205 98 218 115 218 137 186 164 196 176 195 194 178 195 178 183 188 183 169 164 173 144
Polygon -6524078 true true 207 140 200 163 206 175 207 192 193 189 192 177 198 176 185 150
Polygon -6524078 true true 214 134 203 168 192 148
Polygon -6524078 true true 204 151 203 176 193 148
Polygon -6524078 true true 207 103 221 98 236 101 243 115 243 128 256 142 239 143 233 133 225 115 214 114

wolf-right
false
3
Polygon -6524078 true true 170 127 200 93 231 93 237 103 262 103 261 113 253 119 231 119 215 143 213 160 208 173 189 187 169 190 154 190 126 180 106 171 72 171 73 126 122 126 144 123 159 123
Polygon -6524078 true true 201 99 214 69 215 99
Polygon -6524078 true true 207 98 223 71 220 101
Polygon -6524078 true true 184 172 189 234 203 238 203 246 187 247 180 239 171 180
Polygon -6524078 true true 197 174 204 220 218 224 219 234 201 232 195 225 179 179
Polygon -6524078 true true 78 167 95 187 95 208 79 220 92 234 98 235 100 249 81 246 76 241 61 212 65 195 52 170 45 150 44 128 55 121 69 121 81 135
Polygon -6524078 true true 48 143 58 141
Polygon -6524078 true true 46 136 68 137
Polygon -6524078 true true 45 129 35 142 37 159 53 192 47 210 62 238 80 237
Line -16777216 false 74 237 59 213
Line -16777216 false 59 213 59 212
Line -16777216 false 58 211 67 192
Polygon -6524078 true true 38 138 66 149
Polygon -6524078 true true 46 128 33 120 21 118 11 123 3 138 5 160 13 178 9 192 0 199 20 196 25 179 24 161 25 148 45 140
Polygon -6524078 true true 67 122 96 126 63 144

@#$#@#$#@
NetLogo 2.0beta5
@#$#@#$#@
set number-of-groups 25
setup
assign-by-number
repeat 25 [ go ]
@#$#@#$#@
@#$#@#$#@
