breeds [patrons b a r] ;; the 'b', 'a', and 'r' breeds are single turtles that spell 'bar'

;;;;;;;;;;;;;;;
;; Variables ;;
;;;;;;;;;;;;;;;

globals [
  attendance          ;; number of patrons currently attending bar
  sum-attendance      ;; sum of attendance after N days
  days                ;; number of elapsed days
  average-attendance  ;; sum-attendance / days
  regulars            ;; patrons who attend at least every other day
  casuals             ;; patrons who do not attend every other day
]

patrons-own [ 
  attending?          ;; whether or not a patron attended during the previous day
  ;; how often the patron wishes to go to the bar, which is the
  ;; variable c in the Bell and Sethares paper
  attendance-frequency
  ;; the number of days remaining until the patron attends next,
  ;; which is the variable p in the Bell and Sethares paper
  phase
]
    
;;;;;;;;;;;;;;;;;;;;;;;;
;;; Setup Procedures ;;;
;;;;;;;;;;;;;;;;;;;;;;;;
   
to setup
  ca
  setup-world
  setup-patrons
  setup-plot
  update-plots 
end

;; creates the colorful background images in the graphics window
to setup-world
  set sum-attendance 0
  set days 0
  set average-attendance 0
  ask patches
    [ set pcolor scale-color green ((random 500) + 5000) 0 9000 ]
  create-street
  create-bar
end

;; creates a street that runs vertically in the middle of the graphics window
to create-street
  ask patches with [pxcor >= -1 and pxcor <= 1]
    [set pcolor black]
  ask patches with [pxcor = 0 and pycor mod 2 = 0]
    [set pcolor yellow]
end

;; draws in the graphics window a black bar with the word "bar" inside
to create-bar
  ask patches with [pycor < 2 and pycor > -2 and pxcor >= 9 and pxcor < 12]
    [set pcolor black]
  create-custom-b 1
    [set shape "b"
      setxy (screen-edge-x - 2) 0]
  create-custom-a 1
    [set shape "a"
      setxy (screen-edge-x - 1) 0]
  create-custom-r 1
    [set shape "r"
      setxy screen-edge-x 0]  
end

;; creates patrons and places them in unique patches
to setup-patrons
  if population >= (screen-edge-x - 1) * screen-size-y
    [user-message "The population is too large for the size of the world."
        + "  Either decrease the population or increase the number of "
        + "patches in the Graphics Window."
      stop]
  create-custom-patrons population
    [without-interruption
      [set shape "person"
        set color sky
        set size 1
        set attending? false
        set attendance 0
        find-patch
        set attendance-frequency (1 + random 20)   
        set phase (1 + random attendance-frequency) ] ]
end

;; locate unoccupied patches for patrons 
to find-patch
  setxy (-1 - random screen-edge-x ) (random screen-size-y)
  while [any? other-turtles-here]
    [find-patch]    ;; keeps running until each patron is alone on patch
end

;;;;;;;;;;;;;;;;;;;;;;;;;;
;;; Runtime Procedures ;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;

to go
  phase-step
  check-attendance
  update-plots
  phase-update
end

;; counts down phase. if, following this count down, the phase has been completed,
;; the patron will attend now
to phase-step
  ask patrons
    [if (phase > 1) [set phase (phase - 1)]
      if phase <= 1  [set attending? true]]
end

;; checks whether or not the bar is overcrowded
to check-attendance 
  calculate-attendance-by-type
  calculate-average-attendance
  attendees-skip-across-street
  ;; Patrons who are in the bar always have perfect information about attendance
  ;; If the perfect-information? is On, then also patrons who are outside have 
  ;; this information
  ifelse perfect-information?
    [ask patrons [update-attendance-frequency] ] 
    [ask patrons with [attending?] [update-attendance-frequency] ] 
end

;; finds the number of patrons who are attending and determines if they are casuals or regulars           
to calculate-attendance-by-type
  set attendance count patrons with [attending?]
  set regulars count patrons with [attendance-frequency < 3]
  ask patrons with [attendance-frequency < 3]
    [set color red]
  set casuals (population - regulars)
  ask patrons with [attendance-frequency >= 3]
    [set color sky]
end

;; determines the cumulative ratio between total attendance and days since the onset of the 
;; current run of the model
to calculate-average-attendance
  set sum-attendance (sum-attendance + attendance)
  set days (days + 1)
  set average-attendance (sum-attendance / days)
end

;; skips attending customers to the other side of the screen across from the vertical axis
to attendees-skip-across-street
  ask patrons with [attending?]
    [setxy (0 - xcor) ycor]
end

;; patrons update the frequency of their individual attendance schedule (the phase or cycle). 
;; if the bar was crowded, they'll come back less frequently than before, and vice versa
;; returning less frequently means increasing the phase, and vice versa
;; 'frequency-update' is the interface slider value for increasing/decreasing the phase
to update-attendance-frequency ;; patron procedure
  if attendance < (Equilibrium - dead-zone)                
    [if (attendance-frequency > 1)
      [set attendance-frequency (attendance-frequency - frequency-update)]]
  if attendance > Equilibrium 
    [set attendance-frequency (attendance-frequency + frequency-update)]
end

;; updates by setting phase to be attendance-frequency
to phase-update
  ;; now that the day is over, attending patrons return across the street
  ;; these patrons now begin counting down all over again from their current personal
  ;; value of 'attendance-frequency'
  attendees-skip-across-street
  ask patrons with [attending?]
    [set attending? false
      set phase attendance-frequency]
end
      
;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;; Plotting Procedures ;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;      
      
to setup-plot
  set-current-plot "Attendance History"
  set-plot-y-range 0 population
  set-current-plot "Attendance Type"
  set-plot-y-range 0 population
end

to update-plots
  update-attendance
  update-attendance-type
end

to update-attendance
  set-current-plot "Attendance History"
  set-current-plot-pen "now"
  plot attendance
  set-current-plot-pen "cumulative"
  plot average-attendance
end

to update-attendance-type
  set-current-plot "Attendance Type"
  clear-plot
  set-current-plot-pen "casuals"
  plotxy 0 casuals
  set-current-plot-pen "regulars"
  plotxy 1 regulars
end

; *** NetLogo Model Copyright Notice ***
;
; This model was created as part of the projects:
; PARTICIPATORY SIMULATIONS: NETWORK-BASED DESIGN FOR SYSTEMS LEARNING IN
; CLASSROOMS and INTEGRATED SIMULATION AND MODELING ENVIRONMENT.
; The project gratefully acknowledges the support of the
; National Science Foundation (REPP & ROLE programs) -- grant numbers 
; REC #9814682 and REC-0126227.
;
; Copyright 2003 by Uri Wilensky.  Updated 2004.  All rights reserved.
;
; Permission to use, modify or redistribute this model is hereby granted,
; provided that both of the following requirements are followed:
; a) this copyright notice is included.
; b) this model will not be redistributed for profit without permission
;    from Uri Wilensky.
; Contact Uri Wilensky for appropriate licenses for redistribution for
; profit.
;
; To refer to this model in academic publications, please use:
; Wilensky, U. (2004).  NetLogo El Farol model.
; http://ccl.northwestern.edu/netlogo/models/ElFarol.
; Center for Connected Learning and Computer-Based Modeling,
; Northwestern University, Evanston, IL.
;
; In other publications, please use:
; Copyright 2004 Uri Wilensky.  All rights reserved.
; See http://ccl.northwestern.edu/netlogo/models/ElFarol
; for terms of use.
;
; *** End of NetLogo Model Copyright Notice ***
@#$#@#$#@
GRAPHICS-WINDOW
302
10
772
501
11
11
20.0
1
10
1
1
1

CC-WINDOW
302
504
772
605
Command Center

BUTTON
17
10
81
43
Setup
setup
NIL
1
T
OBSERVER
T

BUTTON
194
10
286
43
Go
go
T
1
T
OBSERVER
NIL

SLIDER
19
107
205
140
population
population
0
200
100
1
1
patrons

SLIDER
19
153
205
186
equilibrium
equilibrium
0
100
40
1
1
patrons

SLIDER
18
197
205
230
dead-zone
dead-zone
0
7
2
1
1
patrons

PLOT
18
282
274
426
Attendance History
Time
People
0.0
100.0
0.0
100.0
true
true
PENS
"now" 1.0 0 -6524078 true
"cumulative" 1.0 0 -16711738 true

SLIDER
18
243
205
276
frequency-update
frequency-update
0
50
1
1
1
NIL

BUTTON
100
10
185
43
Go Once
go
NIL
1
T
OBSERVER
T

PLOT
18
439
274
597
Attendance Type
Type
Patrons
0.0
2.0
0.0
100.0
true
true
PENS
"casuals" 1.0 1 -16745473 true
"regulars" 1.0 1 -65536 true

SWITCH
19
63
205
96
perfect-information?
perfect-information?
1
1
-1000

@#$#@#$#@
WHAT IS IT?
-----------
El Farol is a bar in Santa Fe.  The bar is popular, but becomes overcrowded when too many patrons attend.  Patrons are happy when less than a certain amount of patrons attend, say 60 for example, but they are unhappy when more than some other amount of patrons attend, say 70.  What will happen as time passes and people have pleasant or unpleasant experiences?  Is it always true that the more a bar is popular, the higher its attendance?  Does it makes sense to say that a bar "has it's ups and downs, but on the whole it's stable?"

This model problematizes a seemingly simple situation of social interaction to reveal that it is not that simple.  Working in this model, we encounter and appreciate the inherent coordination challenges that can arise in complex dynamic systems involving agents with intention and specified needs and criteria of satisfaction.  Can patrons of a bar somehow self organize to optimize overall satisfaction?


HOW IT WORKS
------------
El Farol is a fun place to be, and patrons keep returning.  But it can get crowded there.  If it is crowded, patrons may not come back as often as they had previously, but if it happens not to be crowded, the patrons will come again sooner.

Patrons of El Farol each have initial inclinations to visit the bar or not.  These personal inclinations are expressed in the frequencies of each patron's visits (the variable ATTENDANCE-FREQUENCY.  For example, a value of 9 means they go to the bar every 9 days).  ATTENDANCE-FREQUENCY is the variable c in the Bell and Sethares paper.  When the model starts running, patrons have different times until their next visit (stored in the variable PHASE. For example, a value of 5 means the patron will go to the bar in 5 days time).  PHASE is the variable p in the Bell and Sethares paper.  For each patron, the initial values of ATTENDANCE-FREQUENCY and PHASE are chosen randomly, within a designated range determined by the other settings of the model.  Each patron's PHASE value decreases as the model runs until it drops below 1, at which time the patron goes to the bar.  While in the bar, the patron determines how crowded the bar is and changes the value of ATTENDANCE-FREQUENCY accordingly.  If attendance at the bar exceeds the EQUILIBRIUM value, i.e. bar is overcrowded, the patron increases ATTENDANCE-FREQUENCY by the FREQUENCY-UPDATE value.  That means that in the future, this patron will wait longer before returning to this bar.  If attendance is below the critical value (EQUILIBRIUM - DEAD-ZONE), i.e. bar is not crowded, the patron decreases ATTENDANCE-FREQUENCY by the FREQUENCY-UPDATE value. ATTENDANCE-FREQUENCY remains unchanged if attendance falls within the DEAD-ZONE range.  The PHASE is then reset to the new value of ATTENDANCE-FREQUENCY.


HOW TO USE IT
-------------
Sliders:
POPULATION      - the number of patrons that will be created in this experiment 
EQUILIBRIUM     - the number of patrons beyond which the bar becomes overcrowded
DEAD-ZONE       - determines the range below the equilibrium at which the bar is perceived neither as crowded nor as not crowded
FREQUENCY-UPDATE - value to update the ATTENDANCE-FREQUENCY by in
                   response to a positive or negative experience at the bar

Buttons:
SETUP 	-  initiates variables towards a new run
GO ONCE      -  runs the model for one time tick, so we get the behavior over a single 'day'
GO - runs the model repeatedly, until it is stopped by pressing again

Switches:
PERFECT-INFORMATION? - if turned on, agents will have access to attendance information whether they are attending or not and will adjust their preferences accordingly

Plots:
ATTENDANCE HISTORY  -  shows how many patrons are currently in the bar and the cumulative ratio of total patrons to total days
ATTENDANCE TYPE     -  shows the current totals of two types of patrons -- casuals and regulars (including those in and out of the bar)

After choosing the variables, click the SETUP button to setup the model. All patrons start on the left side of the screen. This means that none of them are attending the bar at this moment. If they choose to attend, they will move to the right side of the screen. Patrons are colored sky by default. This means that they are 'casual' patrons (less than every other day). If they attend more than every other day, they will turn red to show that they are now 'regular' patrons. 

You can choose between GO ONCE and GO to run the model. Also, for initial runs, you may want to slow down the model, using the speed slider above the Graphics Window, so as to see the patrons attending and leaving the bar.


THINGS TO NOTICE
----------------
Try different settings and examine both plots.  Note that the ATTENDANCE HISTORY plot tends to converge on some value.  Note how the ATTENDANCE TYPE plot occasionally spikes up or down.  This means that there are a lot of casual patrons who are attending the bar often, and once in a while, they all happen to attend on the same day.  With PERFECT-INFORMATION? set to Off, the numbers of casuals and regulars tend to converge on some stable values. You will also notice that the average attendance seems to converge toward the (EQUILIBRIUM - DEAD-ZONE) number. 

When PERFECT-INFORMATION? is turned On, everyone has access to the same information about attendance, and they all respond uniformly by updating their ATTENDANCE-FREQUENCY values.  So the group as a whole usually either all go or they do not go at all.  Thus, an increase in information seems to prevent some wiggle room that would make more patrons satisfied.


THINGS TO TRY
-------------
How does changing the value on the FREQUENCY-UPDATE slider affect the behavior of the system? Try to guess, then run the model under different values for that slider and examine the results. 

Play with the relation between values in the POPULATION and EQUILIBRIUM sliders.  Try to imagine how these settings would impact your own behavior, and see if the model matches your expectations. 


EXTENDING THE MODEL
-------------------
Currently, all patrons have the same tolerance to crowds.  Assign random EQUILIBRIUM values to the attending turtles and evaluate how this modification affects the group behavior.

Invent and implement advanced patron strategies for optimizing their experience at the bar.  One idea is to have patrons remember historical data such as "it is always crowded every 7th day" or "every time it is crowded 4 days in a row, the next day is always not crowded."  What do you expect such an extension might do?  Can we, in principle, guarantee more satisfied patrons by making them more savvy?  Should we give this power of prediction to all patrons, or should we control who has these strategies (just as we controlled who has perfect information)?  Is it fair to favor some patrons over others?

Improve the Graphics Window features.  Perhaps the bar could be made to look more like an actual bar.

A final idea would be to create a HubNet version of the El Farol simulation. 


NETLOGO FEATURES
----------------
Look at the code for procedure attendees-skip-across-street. 

|  to attendees-skip-across-street
|    ask patrons with [attending?]
|    [setxy (0 - xcor) ycor]
|  end

The code asks each patron that has a true value for the 'attending?' (true/false) variable to set their x coordinate.  Yet, this procedure is called both when the patron crosses the street to the right so as to enter the bar and again when the patron exits the bar and crosses back to the left.  How can it be that the same code both sends a patron to the right and to the left? 

The answer lies in the meaning of xcor and how it relates to the minus sign ( - ) just before it. xcor reports a value representing the right/left position of a turtle.  To the right of central vertical line (the y-axis, where the street is in this model), the xcor values are positive, and to the left of the axis the values are negative.  When a patron is in the left section of the graphics window, subtracting the xcor flips the xcor to a positive value.  For instance, if the patron is at (-5, 3), the patron will be sent to (+5, 3).  When this patron has completed attending, this same code sends the patron back from (+5, 3) to (-5, 3).


RELATED MODELS
--------------
The Social Science models Party and Segregation each deal with situations in which individuals have specified preferences and act upon these preferences.


CREDITS AND REFERENCES
----------------------
Original implementation: Eric Cheng, for the Center for Connected Learning and Computer-Based Modeling.

This model is based on a paper by Ann Bell and William Sethares, "The El Farol Problem and the Internet: Congestion and Coordination Failure". 

To refer to this model in academic publications, please use: Wilensky, U. (2004). NetLogo El Farol model. http://ccl.northwestern.edu/netlogo/models/ElFarol. Center for Connected Learning and Computer-Based Modeling, Northwestern University, Evanston, IL.

In other publications, please use: Copyright 2004 Uri Wilensky. All rights reserved. See http://ccl.northwestern.edu/netlogo/models/ElFarol for terms of use.
@#$#@#$#@
default
true
0
Polygon -7566196 true true 150 5 40 250 150 205 260 250

a
false
0
Line -1 false 54 249 150 55
Line -1 false 150 55 253 245
Line -1 false 105 148 201 148

ant
true
0
Polygon -7566196 true true 136 61 129 46 144 30 119 45 124 60 114 82 97 37 132 10 93 36 111 84 127 105 172 105 189 84 208 35 171 11 202 35 204 37 186 82 177 60 180 44 159 32 170 44 165 60
Polygon -7566196 true true 150 95 135 103 139 117 125 149 137 180 135 196 150 204 166 195 161 180 174 150 158 116 164 102
Polygon -7566196 true true 149 186 128 197 114 232 134 270 149 282 166 270 185 232 171 195 149 186 149 186
Polygon -7566196 true true 225 66 230 107 159 122 161 127 234 111 236 106
Polygon -7566196 true true 78 58 99 116 139 123 137 128 95 119
Polygon -7566196 true true 48 103 90 147 129 147 130 151 86 151
Polygon -7566196 true true 65 224 92 171 134 160 135 164 95 175
Polygon -7566196 true true 235 222 210 170 163 162 161 166 208 174
Polygon -7566196 true true 249 107 211 147 168 147 168 150 213 150

arrow
true
0
Polygon -7566196 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

b
false
0
Line -1 false 68 56 70 247
Line -1 false 69 58 114 41
Line -1 false 114 41 143 39
Line -1 false 144 39 166 49
Line -1 false 166 49 187 72
Line -1 false 186 74 190 94
Line -1 false 189 97 193 113
Line -1 false 190 118 185 132
Line -1 false 183 132 162 141
Line -1 false 160 142 137 150
Line -1 false 131 151 108 154
Line -1 false 104 155 73 159
Line -1 false 118 153 145 157
Line -1 false 145 157 170 168
Line -1 false 170 168 187 186
Line -1 false 186 188 195 211
Line -1 false 195 213 192 227
Line -1 false 190 229 178 240
Line -1 false 173 241 163 244
Line -1 false 156 245 137 248
Line -1 false 134 248 117 249
Line -1 false 116 249 107 249
Line -1 false 101 249 85 247
Line -1 false 85 247 73 245

bar
false
0
Line -1 false 13 40 15 241
Line -1 false 16 40 39 41
Line -1 false 39 41 56 48
Line -1 false 56 48 80 67
Line -1 false 80 67 84 84
Line -1 false 84 84 87 105
Line -1 false 86 109 87 121
Line -1 false 85 123 77 132
Line -1 false 75 133 59 139
Line -1 false 53 140 42 142
Line -1 false 38 143 24 145
Line -1 false 19 146 18 147
Line -1 false 20 147 33 148
Line -1 false 33 148 49 154
Line -1 false 49 154 67 167
Line -1 false 67 167 78 177
Line -1 false 79 177 89 191
Line -1 false 90 195 94 209
Line -1 false 94 211 92 221
Line -1 false 89 224 79 228
Line -1 false 76 230 66 232
Line -1 false 60 234 50 235
Line -1 false 45 235 31 235
Line -1 false 31 235 18 238
Line -1 false 102 234 138 105
Line -1 false 138 105 181 230
Line -1 false 114 178 164 178
Line -1 false 195 100 198 236
Line -1 false 193 98 205 92
Line -1 false 205 92 222 90
Line -1 false 222 90 233 92
Line -1 false 233 92 245 100
Line -1 false 245 101 253 119
Line -1 false 254 122 256 133
Line -1 false 256 135 249 148
Line -1 false 246 149 231 159
Line -1 false 230 160 216 163
Line -1 false 212 164 203 165
Line -1 false 198 165 270 242

bee
true
0
Polygon -256 true false 152 149 77 163 67 195 67 211 74 234 85 252 100 264 116 276 134 286 151 300 167 285 182 278 206 260 220 242 226 218 226 195 222 166
Polygon -16777216 true false 150 149 128 151 114 151 98 145 80 122 80 103 81 83 95 67 117 58 141 54 151 53 177 55 195 66 207 82 211 94 211 116 204 139 189 149 171 152
Polygon -7566196 true true 151 54 119 59 96 60 81 50 78 39 87 25 103 18 115 23 121 13 150 1 180 14 189 23 197 17 210 19 222 30 222 44 212 57 192 58
Polygon -16777216 true false 70 185 74 171 223 172 224 186
Polygon -16777216 true false 67 211 71 226 224 226 225 211 67 211
Polygon -16777216 true false 91 257 106 269 195 269 211 255
Line -1 false 144 100 70 87
Line -1 false 70 87 45 87
Line -1 false 45 86 26 97
Line -1 false 26 96 22 115
Line -1 false 22 115 25 130
Line -1 false 26 131 37 141
Line -1 false 37 141 55 144
Line -1 false 55 143 143 101
Line -1 false 141 100 227 138
Line -1 false 227 138 241 137
Line -1 false 241 137 249 129
Line -1 false 249 129 254 110
Line -1 false 253 108 248 97
Line -1 false 249 95 235 82
Line -1 false 235 82 144 100

bird1
false
0
Polygon -7566196 true true 2 6 2 39 270 298 297 298 299 271 187 160 279 75 276 22 100 67 31 0

bird2
false
0
Polygon -7566196 true true 2 4 33 4 298 270 298 298 272 298 155 184 117 289 61 295 61 105 0 43

boat1
false
0
Polygon -1 true false 63 162 90 207 223 207 290 162
Rectangle -6524078 true false 150 32 157 162
Polygon -16776961 true false 150 34 131 49 145 47 147 48 149 49
Polygon -7566196 true true 158 33 230 157 182 150 169 151 157 156
Polygon -7566196 true true 149 55 88 143 103 139 111 136 117 139 126 145 130 147 139 147 146 146 149 55

boat2
false
0
Polygon -1 true false 63 162 90 207 223 207 290 162
Rectangle -6524078 true false 150 32 157 162
Polygon -16776961 true false 150 34 131 49 145 47 147 48 149 49
Polygon -7566196 true true 157 54 175 79 174 96 185 102 178 112 194 124 196 131 190 139 192 146 211 151 216 154 157 154
Polygon -7566196 true true 150 74 146 91 139 99 143 114 141 123 137 126 131 129 132 139 142 136 126 142 119 147 148 147

boat3
false
0
Polygon -1 true false 63 162 90 207 223 207 290 162
Rectangle -6524078 true false 150 32 157 162
Polygon -16776961 true false 150 34 131 49 145 47 147 48 149 49
Polygon -7566196 true true 158 37 172 45 188 59 202 79 217 109 220 130 218 147 204 156 158 156 161 142 170 123 170 102 169 88 165 62
Polygon -7566196 true true 149 66 142 78 139 96 141 111 146 139 148 147 110 147 113 131 118 106 126 71

box
true
0
Polygon -7566196 true true 45 255 255 255 255 45 45 45

butterfly1
true
0
Polygon -16777216 true false 151 76 138 91 138 284 150 296 162 286 162 91
Polygon -7566196 true true 164 106 184 79 205 61 236 48 259 53 279 86 287 119 289 158 278 177 256 182 164 181
Polygon -7566196 true true 136 110 119 82 110 71 85 61 59 48 36 56 17 88 6 115 2 147 15 178 134 178
Polygon -7566196 true true 46 181 28 227 50 255 77 273 112 283 135 274 135 180
Polygon -7566196 true true 165 185 254 184 272 224 255 251 236 267 191 283 164 276
Line -7566196 true 167 47 159 82
Line -7566196 true 136 47 145 81
Circle -7566196 true true 165 45 8
Circle -7566196 true true 134 45 6
Circle -7566196 true true 133 44 7
Circle -7566196 true true 133 43 8

circle
false
0
Circle -7566196 true true 35 35 230

person
false
0
Circle -7566196 true true 155 20 63
Rectangle -7566196 true true 158 79 217 164
Polygon -7566196 true true 158 81 110 129 131 143 158 109 165 110
Polygon -7566196 true true 216 83 267 123 248 143 215 107
Polygon -7566196 true true 167 163 145 234 183 234 183 163
Polygon -7566196 true true 195 163 195 233 227 233 206 159

r
false
0
Line -1 false 71 53 72 252
Line -1 false 73 56 98 42
Line -1 false 98 42 113 41
Line -1 false 113 41 131 44
Line -1 false 131 45 151 53
Line -1 false 151 53 166 68
Line -1 false 166 69 173 91
Line -1 false 173 92 176 116
Line -1 false 174 118 168 144
Line -1 false 163 145 141 155
Line -1 false 138 156 123 161
Line -1 false 119 161 110 162
Line -1 false 107 162 88 165
Line -1 false 85 166 79 166
Line -1 false 115 162 196 256

sheep
false
15
Rectangle -1 true true 90 75 270 225
Circle -1 true true 15 75 150
Rectangle -16777216 true false 81 225 134 286
Rectangle -16777216 true false 180 225 238 285
Circle -16777216 true false 1 88 92

spacecraft
true
0
Polygon -7566196 true true 150 0 180 135 255 255 225 240 150 180 75 240 45 255 120 135

thin-arrow
true
0
Polygon -7566196 true true 150 0 0 150 120 150 120 293 180 293 180 150 300 150

truck-down
false
0
Polygon -7566196 true true 225 30 225 270 120 270 105 210 60 180 45 30 105 60 105 30
Polygon -8716033 true false 195 75 195 120 240 120 240 75
Polygon -8716033 true false 195 225 195 180 240 180 240 225

truck-left
false
0
Polygon -7566196 true true 120 135 225 135 225 210 75 210 75 165 105 165
Polygon -8716033 true false 90 210 105 225 120 210
Polygon -8716033 true false 180 210 195 225 210 210

truck-right
false
0
Polygon -7566196 true true 180 135 75 135 75 210 225 210 225 165 195 165
Polygon -8716033 true false 210 210 195 225 180 210
Polygon -8716033 true false 120 210 105 225 90 210

turtle
true
0
Polygon -7566196 true true 138 75 162 75 165 105 225 105 225 142 195 135 195 187 225 195 225 225 195 217 195 202 105 202 105 217 75 225 75 195 105 187 105 135 75 142 75 105 135 105

wolf
false
0
Rectangle -7566196 true true 15 105 105 165
Rectangle -7566196 true true 45 90 105 105
Polygon -7566196 true true 60 90 83 44 104 90
Polygon -16777216 true false 67 90 82 59 97 89
Rectangle -1 true false 48 93 59 105
Rectangle -16777216 true false 51 96 55 101
Rectangle -16777216 true false 0 121 15 135
Rectangle -16777216 true false 15 136 60 151
Polygon -1 true false 15 136 23 149 31 136
Polygon -1 true false 30 151 37 136 43 151
Rectangle -7566196 true true 105 120 263 195
Rectangle -7566196 true true 108 195 259 201
Rectangle -7566196 true true 114 201 252 210
Rectangle -7566196 true true 120 210 243 214
Rectangle -7566196 true true 115 114 255 120
Rectangle -7566196 true true 128 108 248 114
Rectangle -7566196 true true 150 105 225 108
Rectangle -7566196 true true 132 214 155 270
Rectangle -7566196 true true 110 260 132 270
Rectangle -7566196 true true 210 214 232 270
Rectangle -7566196 true true 189 260 210 270
Line -7566196 true 263 127 281 155
Line -7566196 true 281 155 281 192

wolf-left
false
3
Polygon -6524078 true true 117 97 91 74 66 74 60 85 36 85 38 92 44 97 62 97 81 117 84 134 92 147 109 152 136 144 174 144 174 103 143 103 134 97
Polygon -6524078 true true 87 80 79 55 76 79
Polygon -6524078 true true 81 75 70 58 73 82
Polygon -6524078 true true 99 131 76 152 76 163 96 182 104 182 109 173 102 167 99 173 87 159 104 140
Polygon -6524078 true true 107 138 107 186 98 190 99 196 112 196 115 190
Polygon -6524078 true true 116 140 114 189 105 137
Rectangle -6524078 true true 109 150 114 192
Rectangle -6524078 true true 111 143 116 191
Polygon -6524078 true true 168 106 184 98 205 98 218 115 218 137 186 164 196 176 195 194 178 195 178 183 188 183 169 164 173 144
Polygon -6524078 true true 207 140 200 163 206 175 207 192 193 189 192 177 198 176 185 150
Polygon -6524078 true true 214 134 203 168 192 148
Polygon -6524078 true true 204 151 203 176 193 148
Polygon -6524078 true true 207 103 221 98 236 101 243 115 243 128 256 142 239 143 233 133 225 115 214 114

wolf-right
false
3
Polygon -6524078 true true 170 127 200 93 231 93 237 103 262 103 261 113 253 119 231 119 215 143 213 160 208 173 189 187 169 190 154 190 126 180 106 171 72 171 73 126 122 126 144 123 159 123
Polygon -6524078 true true 201 99 214 69 215 99
Polygon -6524078 true true 207 98 223 71 220 101
Polygon -6524078 true true 184 172 189 234 203 238 203 246 187 247 180 239 171 180
Polygon -6524078 true true 197 174 204 220 218 224 219 234 201 232 195 225 179 179
Polygon -6524078 true true 78 167 95 187 95 208 79 220 92 234 98 235 100 249 81 246 76 241 61 212 65 195 52 170 45 150 44 128 55 121 69 121 81 135
Polygon -6524078 true true 48 143 58 141
Polygon -6524078 true true 46 136 68 137
Polygon -6524078 true true 45 129 35 142 37 159 53 192 47 210 62 238 80 237
Line -16777216 false 74 237 59 213
Line -16777216 false 59 213 59 212
Line -16777216 false 58 211 67 192
Polygon -6524078 true true 38 138 66 149
Polygon -6524078 true true 46 128 33 120 21 118 11 123 3 138 5 160 13 178 9 192 0 199 20 196 25 179 24 161 25 148 45 140
Polygon -6524078 true true 67 122 96 126 63 144

@#$#@#$#@
NetLogo 2.0.1
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
